[![GitHub issues](https://img.shields.io/github/issues/amickael/pyopentdb)](https://github.com/amickael/pyopentdb/issues)
![PyPI](https://img.shields.io/pypi/v/pyopentdb?color=blue)
![PyPI - Downloads](https://img.shields.io/pypi/dw/pyopentdb?color=red)
[![GitHub license](https://img.shields.io/github/license/amickael/pyopentdb?color=purple)](https://github.com/amickael/pyopentdb/blob/master/LICENSE)
[![Code style](https://img.shields.io/badge/code%20style-black-black)](https://github.com/psf/black)

# pyopentdb
Python interface for the Open Trivia DB API

## 👶 Dependencies
* [Python 3.6 or higher](https://www.python.org/downloads/)

## 🛠️ Installation
Install from PyPI using `pip`, you may need to use `pip3` depending on your installation
```sh
pip install pyopentdb
```

## 🚀 Usage
